"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const documenter_ui_section_1 = require("@teambit/documenter.ui.section");
const documenter_theme_theme_context_1 = require("@teambit/documenter.theme.theme-context");
const documenter_ui_separator_1 = require("@teambit/documenter.ui.separator");
const workspace_1 = require("@teambit/workspace");
const component_tooltip_1 = require("./component-tooltip");
function Overview() {
    return (react_1.default.createElement(documenter_theme_theme_context_1.ThemeContext, null,
        react_1.default.createElement(react_1.default.Fragment, null,
            react_1.default.createElement(documenter_ui_section_1.Section, null, "The tooltip handles the presentation of the status as well (modified, errors etc.)"),
            react_1.default.createElement(documenter_ui_separator_1.Separator, null))));
}
exports.default = Overview;
Overview.abstract = 'Tooltip status';
Overview.labels = ['react', 'typescript', 'tooltip'];
const style = { display: 'flex', justifyContent: 'center', alignContent: 'center', margin: 8 };
Overview.examples = [
    {
        scope: {
            StatusProps: workspace_1.ComponentStatus,
            StatusTooltip: component_tooltip_1.StatusTooltip,
            style,
        },
        title: 'New status',
        description: 'Using the Component Tooltip with new status',
        code: `
    () => {
      const modifyInfo = { hasModifiedFiles: false, hasModifiedDependencies: false };
      const isNew = true;
      const isDeleted = false;
      const isStaged = false;
      const isInWorkspace = false;
      const isInScope = false;
      const nested = false;
      const compStatus = new StatusProps(modifyInfo, isNew, isDeleted, isStaged, isInWorkspace, isInScope, nested);
      return (
        <div style={style}>
            <StatusTooltip status={compStatus}>
              N
            </StatusTooltip>
        </div>
      );
    }
      `,
    },
    {
        scope: {
            StatusProps: workspace_1.ComponentStatus,
            StatusTooltip: component_tooltip_1.StatusTooltip,
            style,
        },
        title: 'Staged status',
        description: 'Using the Component Tooltip with staged status',
        code: `
    () => {
      const modifyInfo = { hasModifiedFiles: false, hasModifiedDependencies: false };
      const isNew = false;
      const isDeleted = false;
      const isStaged = true;
      const isInWorkspace = false;
      const isInScope = false;
      const nested = false;
      const compStatus = new StatusProps(modifyInfo, isNew, isDeleted, isStaged, isInWorkspace, isInScope, nested);
      return (
        <div style={style}>
          <StatusTooltip status={compStatus} >
            S
          </StatusTooltip>
        </div>
      );
    }
      `,
    },
    {
        scope: {
            StatusProps: workspace_1.ComponentStatus,
            StatusTooltip: component_tooltip_1.StatusTooltip,
            style,
        },
        title: 'Modified files and dependencies status',
        description: 'Using the Component Tooltip with modified status',
        code: `
    () => {
      const modifyInfo = { hasModifiedFiles: true, hasModifiedDependencies: true };
      const isNew = false;
      const isDeleted = false;
      const isStaged = false;
      const isInWorkspace = false;
      const isInScope = false;
      const nested = false;
      const compStatus = new StatusProps(modifyInfo, isNew, isDeleted, isStaged, isInWorkspace, isInScope, nested);
      return (
        <div style={style}>
          <StatusTooltip status={compStatus} >
            M
          </StatusTooltip>
        </div>
      );
    }
      `,
    },
    {
        scope: {
            StatusProps: workspace_1.ComponentStatus,
            StatusTooltip: component_tooltip_1.StatusTooltip,
            style,
        },
        title: 'Modified files status and issues',
        description: 'Using the Component Tooltip with modified files and issues',
        code: `
    () => {
      const modifyInfo = { hasModifiedFiles: true, hasModifiedDependencies: false };
      const isNew = false;
      const isDeleted = false;
      const isStaged = false;
      const isInWorkspace = false;
      const isInScope = false;
      const nested = false;
      const compStatus = new StatusProps(modifyInfo, isNew, isDeleted, isStaged, isInWorkspace, isInScope, nested);
      return (
        <div style={style}>
          <StatusTooltip status={compStatus} issuesCount={2} >
            M
          </StatusTooltip>
        </div>
      );
    }
      `,
    },
];
//# sourceMappingURL=component-tooltip.docs.js.map